# 027

|                                                                          | 027-washing-machine-wm22-b2plus   | 027-000                 |
|:-------------------------------------------------------------------------|:----------------------------------|:------------------------|
| bindTime                                                                 | 1737322075186                     | 1685083566362           |
| createTime                                                               | 0                                 | 0                       |
| deviceFeatureCode                                                        | washing-machine-wm22-b2plus       | 000                     |
| deviceFeatureName                                                        | WASHING-MACHINE-WM22-B2PLUS       | W-WaveEn-22             |
| deviceId                                                                 | <redacted>                        | <redacted>              |
| deviceNickName                                                           | Washing Machine                   | Gorenje washing machine |
| deviceTypeCode                                                           | 027                               | 027                     |
| deviceTypeName                                                           |                                   |                         |
| isShow                                                                   | 1                                 |                         |
| offlineState                                                             | 1                                 | 1                       |
| puid                                                                     | <redacted>                        | <redacted>              |
| role                                                                     | 1                                 | 2                       |
| roomId                                                                   | 7040508                           | 106345                  |
| roomName                                                                 | Vasketøjsrum                      | default_room            |
| seq                                                                      | 0                                 | 0                       |
| statusList.ADS_Dirtiness_setting_status                                  | 0                                 | 0                       |
| statusList.ADS_Settings_Current_Program_Detergent_setting_status         |                                   | 0                       |
| statusList.ADS_Settings_Current_Program_Softener_setting_status          |                                   | 0                       |
| statusList.Adapt_sense_setting_status                                    | 1                                 | 2                       |
| statusList.Add_on_program_download_ID                                    |                                   | 0                       |
| statusList.Add_on_program_download_status                                |                                   | 0                       |
| statusList.Add_program_to_device                                         |                                   | 0                       |
| statusList.Air_dry_function_status                                       | 1                                 | 0                       |
| statusList.Air_shower_setting_status                                     |                                   | 0                       |
| statusList.Alarm_1                                                       | 1                                 | 1                       |
| statusList.Alarm_10                                                      | 0                                 | 1                       |
| statusList.Alarm_11                                                      | 0                                 | 1                       |
| statusList.Alarm_12                                                      | 1                                 | 1                       |
| statusList.Alarm_13                                                      | 0                                 | 0                       |
| statusList.Alarm_14                                                      | 1                                 | 1                       |
| statusList.Alarm_15                                                      | 1                                 | 1                       |
| statusList.Alarm_16                                                      | 1                                 | 1                       |
| statusList.Alarm_17                                                      |                                   | 0                       |
| statusList.Alarm_18                                                      |                                   | 0                       |
| statusList.Alarm_19                                                      |                                   | 0                       |
| statusList.Alarm_2                                                       | 1                                 | 1                       |
| statusList.Alarm_20                                                      |                                   | 0                       |
| statusList.Alarm_21                                                      |                                   | 0                       |
| statusList.Alarm_22                                                      |                                   | 0                       |
| statusList.Alarm_3                                                       | 1                                 | 1                       |
| statusList.Alarm_4                                                       | 1                                 | 1                       |
| statusList.Alarm_5                                                       | 1                                 | 1                       |
| statusList.Alarm_6                                                       | 0                                 | 0                       |
| statusList.Alarm_7                                                       | 0                                 | 1                       |
| statusList.Alarm_8                                                       | 0                                 | 1                       |
| statusList.Alarm_9                                                       | 1                                 | 1                       |
| statusList.Auto_Super_rinse_setting_status                               |                                   | 0                       |
| statusList.Auto_dose_Compartment1_amount_setting                         | 255                               | 0                       |
| statusList.Auto_dose_Compartment1_status_102                             |                                   | 0                       |
| statusList.Auto_dose_Compartment1_tank_amount                            | 0                                 | 7                       |
| statusList.Auto_dose_Compartment2_amount_setting                         | 255                               | 0                       |
| statusList.Auto_dose_Compartment2_status_102                             |                                   | 0                       |
| statusList.Auto_dose_Compartment2_tank_amount                            | 0                                 | 3                       |
| statusList.Auto_dose_drawer_status                                       |                                   | 0                       |
| statusList.Auto_dose_system_setting_status                               | 0                                 | 0                       |
| statusList.Brightness_setting                                            |                                   | 0                       |
| statusList.Can_upload_WiFi_program                                       |                                   | 0                       |
| statusList.Child_lock_setting_status                                     | 2                                 | 2                       |
| statusList.Child_lock_status_status                                      | 1                                 | 1                       |
| statusList.Color_sensor_setting_status                                   | 0                                 | 0                       |
| statusList.Compartment1_type_setting_status                              | 0                                 | 0                       |
| statusList.Compartment2_type_setting_status                              | 0                                 | 0                       |
| statusList.Current_temperature                                           |                                   | 0                       |
| statusList.Current_washing_program_phase_2                               | 1                                 | 1                       |
| statusList.Current_washing_program_phase_status                          | 15                                | 15                      |
| statusList.Current_water_level                                           |                                   | 0                       |
| statusList.Darhcdq                                                       | 65535                             | 65535                   |
| statusList.Delay_start_remaining_time_in_minutes                         | 0                                 | 65535                   |
| statusList.Delaystart_delayend_mode_status                               | 1                                 | 1                       |
| statusList.Delaystart_delayend_remaining_time_in_minutes                 | 38400                             | 65535                   |
| statusList.Delaystart_delayend_timestamp_status                          | 16679/02/18T23:47:45              | 16679/02/18T23:47:45    |
| statusList.Demo_mode_status                                              |                                   | 0                       |
| statusList.Detergent_amount_status                                       | 0                                 | 0                       |
| statusList.Detergent_indicator                                           | 0                                 | 0                       |
| statusList.Door_status                                                   | 2                                 | 2                       |
| statusList.Dose_assist_recommended_detergent_quantity_unit_status        | 0                                 | 1                       |
| statusList.Dose_assist_recommended_low_concenatration_detergent_quantity | 65535                             | 65535                   |
| statusList.Dose_assist_status                                            | 0                                 | 0                       |
| statusList.Drum_light_setting_status                                     |                                   | 0                       |
| statusList.Error_0                                                       | 1                                 | 1                       |
| statusList.Error_1                                                       | 1                                 | 1                       |
| statusList.Error_10                                                      | 1                                 | 1                       |
| statusList.Error_11                                                      | 1                                 | 1                       |
| statusList.Error_12                                                      | 1                                 | 1                       |
| statusList.Error_12_1                                                    | 1                                 | 1                       |
| statusList.Error_12_10                                                   | 1                                 | 1                       |
| statusList.Error_12_11                                                   | 0                                 | 1                       |
| statusList.Error_12_12                                                   | 1                                 | 1                       |
| statusList.Error_12_13                                                   | 0                                 | 1                       |
| statusList.Error_12_14                                                   | 0                                 | 1                       |
| statusList.Error_12_15                                                   | 0                                 | 1                       |
| statusList.Error_12_16                                                   | 0                                 | 1                       |
| statusList.Error_12_17                                                   | 0                                 | 0                       |
| statusList.Error_12_18                                                   |                                   | 0                       |
| statusList.Error_12_2                                                    | 1                                 | 1                       |
| statusList.Error_12_3                                                    | 1                                 | 1                       |
| statusList.Error_12_4                                                    | 1                                 | 1                       |
| statusList.Error_12_5                                                    | 1                                 | 1                       |
| statusList.Error_12_6                                                    | 1                                 | 1                       |
| statusList.Error_12_7                                                    | 0                                 | 1                       |
| statusList.Error_12_8                                                    | 1                                 | 1                       |
| statusList.Error_12_9                                                    | 1                                 | 1                       |
| statusList.Error_13                                                      | 1                                 | 1                       |
| statusList.Error_13_1                                                    | 1                                 | 1                       |
| statusList.Error_13_2                                                    | 1                                 | 1                       |
| statusList.Error_13_3                                                    | 1                                 | 1                       |
| statusList.Error_14                                                      | 0                                 | 0                       |
| statusList.Error_15                                                      | 1                                 | 1                       |
| statusList.Error_16                                                      | 0                                 | 0                       |
| statusList.Error_17                                                      | 0                                 | 0                       |
| statusList.Error_18                                                      | 0                                 | 0                       |
| statusList.Error_19                                                      | 0                                 | 0                       |
| statusList.Error_2                                                       | 1                                 | 1                       |
| statusList.Error_20                                                      | 0                                 | 0                       |
| statusList.Error_21                                                      | 0                                 | 0                       |
| statusList.Error_22                                                      | 1                                 | 1                       |
| statusList.Error_23                                                      | 1                                 | 1                       |
| statusList.Error_24                                                      | 0                                 | 0                       |
| statusList.Error_25                                                      | 0                                 | 0                       |
| statusList.Error_26                                                      | 0                                 | 0                       |
| statusList.Error_27                                                      | 0                                 | 0                       |
| statusList.Error_28                                                      | 0                                 | 0                       |
| statusList.Error_29                                                      | 0                                 | 0                       |
| statusList.Error_3                                                       | 1                                 | 1                       |
| statusList.Error_30                                                      | 1                                 | 0                       |
| statusList.Error_31                                                      | 0                                 | 0                       |
| statusList.Error_32                                                      | 0                                 | 0                       |
| statusList.Error_33                                                      | 0                                 | 0                       |
| statusList.Error_34                                                      | 0                                 | 0                       |
| statusList.Error_35                                                      | 0                                 | 0                       |
| statusList.Error_36                                                      | 0                                 | 1                       |
| statusList.Error_37                                                      | 1                                 | 1                       |
| statusList.Error_38                                                      | 0                                 | 0                       |
| statusList.Error_38_1                                                    |                                   | 0                       |
| statusList.Error_39                                                      | 0                                 | 0                       |
| statusList.Error_4                                                       | 0                                 | 0                       |
| statusList.Error_40                                                      | 1                                 | 1                       |
| statusList.Error_41                                                      | 1                                 | 1                       |
| statusList.Error_42                                                      | 1                                 | 1                       |
| statusList.Error_43                                                      | 1                                 | 1                       |
| statusList.Error_44                                                      | 1                                 | 1                       |
| statusList.Error_45                                                      | 0                                 | 0                       |
| statusList.Error_46                                                      | 1                                 | 1                       |
| statusList.Error_47                                                      | 1                                 | 0                       |
| statusList.Error_48                                                      | 1                                 | 1                       |
| statusList.Error_49                                                      |                                   | 0                       |
| statusList.Error_5                                                       | 0                                 | 0                       |
| statusList.Error_50                                                      |                                   | 0                       |
| statusList.Error_51                                                      |                                   | 0                       |
| statusList.Error_52                                                      |                                   | 0                       |
| statusList.Error_6                                                       | 1                                 | 1                       |
| statusList.Error_7                                                       | 1                                 | 1                       |
| statusList.Error_7_1                                                     | 1                                 | 1                       |
| statusList.Error_7_2                                                     |                                   | 0                       |
| statusList.Error_8                                                       | 1                                 | 1                       |
| statusList.Error_89                                                      | 0                                 | 1                       |
| statusList.Error_9                                                       | 1                                 | 1                       |
| statusList.Error_90                                                      | 0                                 | 1                       |
| statusList.Error_9_1                                                     |                                   | 0                       |
| statusList.Extra_rinse_status                                            | 1                                 | 0                       |
| statusList.Fota                                                          | 0                                 | 4                       |
| statusList.HardPairingStatus                                             | 0                                 | 0                       |
| statusList.Language_setting                                              | 0                                 | 0                       |
| statusList.Liquid_unit_setting_status                                    |                                   | 0                       |
| statusList.Logo_setting_status                                           | 0                                 | 3                       |
| statusList.Max_RPM_allowed_stat                                          |                                   | 0                       |
| statusList.Night_start_setting_status_102                                | 0                                 | 1                       |
| statusList.No_sound_status                                               | 1                                 | 1                       |
| statusList.Number_of_rinses                                              |                                   | 0                       |
| statusList.Power_save_status                                             | 1                                 | 0                       |
| statusList.Remote_control_mode_monitoring                                | 1                                 | 1                       |
| statusList.Remote_control_monitoring_set_commands                        | 1                                 | 1                       |
| statusList.Remote_control_monitoring_set_commands_actions                | 0                                 | 0                       |
| statusList.Selected_program_Disinfection                                 | 0                                 | 0                       |
| statusList.Selected_program_Eco_Disinfection                             |                                   | 0                       |
| statusList.Selected_program_Eco_Green_mode                               |                                   | 0                       |
| statusList.Selected_program_Eco_Small_load                               |                                   | 0                       |
| statusList.Selected_program_Eco_Speed_mode                               |                                   | 0                       |
| statusList.Selected_program_Green_leaves_AntiCrease                      |                                   | 0                       |
| statusList.Selected_program_Green_leaves_Entry_steam                     |                                   | 0                       |
| statusList.Selected_program_Green_leaves_Prewash                         |                                   | 0                       |
| statusList.Selected_program_Intensive_mode                               |                                   | 0                       |
| statusList.Selected_program_Night_mode                                   |                                   | 0                       |
| statusList.Selected_program_Small_load_status                            | 0                                 | 1                       |
| statusList.Selected_program_Super_rinse                                  |                                   | 0                       |
| statusList.Selected_program_Water_add                                    |                                   | 0                       |
| statusList.Selected_program_anticrease_status                            | 1                                 | 0                       |
| statusList.Selected_program_duration_in_minutes                          | 0                                 | 1023                    |
| statusList.Selected_program_entry_steam_status                           | 0                                 | 0                       |
| statusList.Selected_program_id_status                                    | 8                                 | 255                     |
| statusList.Selected_program_load_status                                  | 0                                 | 0                       |
| statusList.Selected_program_mode2_status                                 | 0                                 | 0                       |
| statusList.Selected_program_mode_status                                  | 1                                 | 0                       |
| statusList.Selected_program_prewash_status                               | 1                                 | 0                       |
| statusList.Selected_program_remaining_time_in_minutes                    | 150                               | 1023                    |
| statusList.Selected_program_rinse_hold_status                            | 1                                 | 0                       |
| statusList.Selected_program_set_temperature_status                       | 3                                 | 0                       |
| statusList.Selected_program_washing_spin_speed_rpm_status                | 8                                 | 0                       |
| statusList.Selected_program_water_pluse_status                           | 1                                 | 0                       |
| statusList.Session_pairing_active                                        | 0                                 | 0                       |
| statusList.Session_pairing_status                                        | 0                                 | 0                       |
| statusList.Smart_sync_setting_status                                     |                                   | 0                       |
| statusList.Soft_pairing_status                                           | 0                                 | 0                       |
| statusList.Softener_amount_status                                        | 0                                 | 0                       |
| statusList.Softener_indicator                                            | 0                                 | 0                       |
| statusList.Sound_setting_status                                          | 4                                 | 3                       |
| statusList.Stain_program_Set_clothes_type_status                         |                                   | 0                       |
| statusList.Stain_program_Set_stain_status                                |                                   | 0                       |
| statusList.Status                                                        | 4                                 | 0                       |
| statusList.StopAddGoAllowed                                              | 1                                 | 2                       |
| statusList.Stopaddgo_status                                              | 1                                 | 1                       |
| statusList.Temperature_unit_setting_status                               |                                   | 0                       |
| statusList.Time_program_Set_time_status                                  |                                   | 0                       |
| statusList.Time_save_status                                              | 0                                 | 0                       |
| statusList.Turbidity_sensor_setting_status                               | 0                                 | 3                       |
| statusList.Units_setting_status                                          | 0                                 | 3                       |
| statusList.View_size_setting_status                                      |                                   | 0                       |
| statusList.Volume_setting                                                | 0                                 | 25                      |
| statusList.Water_hardness_setting_status                                 | 0                                 | 2                       |
| statusList.Weight_unit_setting_status                                    |                                   | 0                       |
| statusList.daily_energy_kwh                                              | 0                                 | 0                       |
| useTime                                                                  | 1737129803685                     | 0                       |
| wifiId                                                                   | <redacted>                        | <redacted>              |

## Generated from

- [`027`](027-washing-machine-wm22-b2plus.json)
- [`027`](027-000.json)
